@@ -63,6 +63,8 @@ class BaseDatabase(ABC):
     # illegal_column_name_chars[0] will be replaced by value in illegal_column_name_chars_replacement[0]
     illegal_column_name_chars: list[str] = []
     illegal_column_name_chars_replacement: list[str] = []
+    # In run_raw_sql operator decides if we want to return results directly or process them by handler provided
+    IGNORE_HANDLER_IN_RUN_RAW_SQL: bool = False
     NATIVE_PATHS: dict[Any, Any] = {}
     DEFAULT_SCHEMA = SCHEMA
     NATIVE_LOAD_EXCEPTIONS: Any = DatabaseCustomError
@@ -115,6 +117,7 @@ class BaseDatabase(ABC):
 
         :param sql: Contains SQL query to be run against database
         :param parameters: Optional parameters to be used to render the query
+        :param autocommit: Optional autocommit flag
         """
         if parameters is None:
             parameters = {}
@@ -458,7 +461,6 @@ class BaseDatabase(ABC):
         if use_native_support and self.is_native_load_file_available(
             source_file=input_file, target_table=output_table
         ):
-
             self.load_file_to_table_natively_with_fallback(
                 source_file=input_file,
                 target_table=output_table,
