@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import warnings
 from typing import Any
 
 import pandas as pd
@@ -17,7 +18,7 @@ from astro.options import LoadOptions, LoadOptionsList
 from astro.settings import LOAD_FILE_ENABLE_NATIVE_FALLBACK
 from astro.sql.operators.base_operator import AstroSQLBaseOperator
 from astro.table import BaseTable
-from astro.utils.typing_compat import Context
+from astro.utils.compat.typing import Context
 
 
 class LoadFileOperator(AstroSQLBaseOperator):
@@ -62,6 +63,13 @@ class LoadFileOperator(AstroSQLBaseOperator):
                 output_datasets=output_table,
             )
         )
+        if native_support_kwargs:
+            warnings.warn(
+                """`load_options` will replace `native_support_kwargs` parameter in astro-sdk-python>=1.5.0. Please
+                use `load_options` parameter instead.""",
+                DeprecationWarning,
+                stacklevel=2,
+            )
         self.output_table = output_table
         self.input_file = input_file
         self.input_file.load_options = load_options
@@ -82,6 +90,7 @@ class LoadFileOperator(AstroSQLBaseOperator):
         """
         if self.input_file.conn_id:
             check_if_connection_exists(self.input_file.conn_id)
+
         # TODO: remove pushing to XCom once we update the airflow version.
         if self.output_table:
             context["ti"].xcom_push(key="output_table_conn_id", value=str(self.output_table.conn_id))
@@ -89,7 +98,6 @@ class LoadFileOperator(AstroSQLBaseOperator):
         return self.load_data(input_file=self.input_file, context=context)
 
     def load_data(self, input_file: File, context: Context) -> BaseTable | pd.DataFrame:
-
         self.log.info("Loading %s into %s ...", self.input_file.path, self.output_table)
         if self.output_table:
             return self.load_data_to_table(input_file, context)
@@ -329,6 +337,14 @@ def load_file(
     # contain chars like - ?, * etc. Which are not acceptable as task id.
     task_id = task_id if task_id is not None else get_unique_task_id("load_file")
 
+    if native_support_kwargs:
+        warnings.warn(
+            """`load_options` will replace `native_support_kwargs` parameter in astro-sdk-python>=1.5.0. Please use
+            `load_options` parameter instead.""",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+
     return LoadFileOperator(
         task_id=task_id,
         input_file=input_file,
